@@ -25,39 +25,39 @@ THE SOFTWARE.
 const std::map<llvm::StringRef, hipCounter> CUDA_TENSOR_FUNCTION_MAP {
   {"cutensorCreate",                                 {"hiptensorCreate",                                     "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorDestroy",                                {"hiptensorDestroy",                                    "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorHandleResizePlanCache",                  {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorHandleWritePlanCacheToFile",             {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorHandleReadPlanCacheFromFile",            {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorWriteKernelCacheToFile",                 {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorReadKernelCacheFromFile",                {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreateTensorDescriptor",                 {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorInitTensorDescriptor",                   {"hiptensorInitTensorDescriptor",                       "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorDestroyTensorDescriptor",                {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreateElementwiseTrinary",               {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorElementwiseTrinaryExecute",              {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreateElementwiseBinary",                {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorElementwiseBinaryExecute",               {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreatePermutation",                      {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorHandleResizePlanCache",                  {"hiptensorHandleResizePlanCache",                      "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorHandleWritePlanCacheToFile",             {"hiptensorHandleWritePlanCacheToFile",                 "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorHandleReadPlanCacheFromFile",            {"hiptensorHandleReadPlanCacheFromFile",                "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorWriteKernelCacheToFile",                 {"hiptensorWriteKernelCacheToFile",                     "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorReadKernelCacheFromFile",                {"hiptensorReadKernelCacheFromFile",                    "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreateTensorDescriptor",                 {"hiptensorCreateTensorDescriptor",                     "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorInitTensorDescriptor",                   {"hiptensorInitTensorDescriptor",                       "", CONV_LIB_FUNC, API_TENSOR, 2, HIP_REMOVED}},
+  {"cutensorDestroyTensorDescriptor",                {"hiptensorDestroyTensorDescriptor",                    "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreateElementwiseTrinary",               {"hiptensorCreateElementwiseTrinary",                   "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorElementwiseTrinaryExecute",              {"hiptensorElementwiseTrinaryExecute",                  "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreateElementwiseBinary",                {"hiptensorCreateElementwiseBinary",                    "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorElementwiseBinaryExecute",               {"hiptensorElementwiseBinaryExecute",                   "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreatePermutation",                      {"hiptensorCreatePermutation",                          "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorPermutation",                            {"hiptensorPermutation",                                "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorPermute",                                {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreateContraction",                      {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorContraction",                            {"hiptensorContraction",                                "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorDestroyOperationDescriptor",             {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorOperationDescriptorSetAttribute",        {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorOperationDescriptorGetAttribute",        {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreatePlanPreference",                   {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorDestroyPlanPreference",                  {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorPlanPreferenceSetAttribute",             {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorPlanGetAttribute",                       {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorEstimateWorkspaceSize",                  {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorCreatePlan",                             {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorDestroyPlan",                            {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorContract",                               {"hiptensorContraction",                                "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorPermute",                                {"hiptensorPermute",                                    "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreateContraction",                      {"hiptensorCreateContraction",                          "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorContraction",                            {"hiptensorContraction",                                "", CONV_LIB_FUNC, API_TENSOR, 2, HIP_REMOVED}},
+  {"cutensorDestroyOperationDescriptor",             {"hiptensorDestroyOperationDescriptor",                 "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorOperationDescriptorSetAttribute",        {"hiptensorOperationDescriptorSetAttribute",            "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorOperationDescriptorGetAttribute",        {"hiptensorOperationDescriptorGetAttribute",            "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreatePlanPreference",                   {"hiptensorCreatePlanPreference",                       "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorDestroyPlanPreference",                  {"hiptensorDestroyPlanPreference",                      "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorPlanPreferenceSetAttribute",             {"hiptensorPlanPreferenceSetAttribute",                 "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorPlanGetAttribute",                       {"hiptensorPlanGetAttribute",                           "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorEstimateWorkspaceSize",                  {"hiptensorEstimateWorkspaceSize",                      "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorCreatePlan",                             {"hiptensorCreatePlan",                                 "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorDestroyPlan",                            {"hiptensorDestroyPlan",                                "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorContract",                               {"hiptensorContract",                                   "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorReduction",                              {"hiptensorReduction",                                  "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorCreateReduction",                        {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
-  {"cutensorReduce",                                 {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorCreateReduction",                        {"hiptensorCreateReduction",                            "", CONV_LIB_FUNC, API_TENSOR, 2}},
+  {"cutensorReduce",                                 {"hiptensorReduce",                                     "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorGetErrorString",                         {"hiptensorGetErrorString",                             "", CONV_LIB_FUNC, API_TENSOR, 2}},
-  {"cutensorGetVersion",                             {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorGetVersion",                             {"hiptensorGetVersion",                                 "", CONV_LIB_FUNC, API_TENSOR, 2, HIP_EXPERIMENTAL}},
   {"cutensorGetCudartVersion",                       {"hiptensorGetHiprtVersion",                            "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorLoggerSetCallback",                      {"hiptensorLoggerSetCallback",                          "", CONV_LIB_FUNC, API_TENSOR, 2}},
   {"cutensorLoggerSetFile",                          {"hiptensorLoggerSetFile",                              "", CONV_LIB_FUNC, API_TENSOR, 2}},
@@ -84,6 +84,12 @@ const std::map<llvm::StringRef, hipCounter> CUDA_TENSOR_FUNCTION_MAP {
   {"cutensorMgCreateContractionPlan",                {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
   {"cutensorMgDestroyContractionPlan",               {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
   {"cutensorMgContraction",                          {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorCreateContractionTrinary",               {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorContractTrinary",                        {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorCreateBlockSparseTensorDescriptor",      {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorDestroyBlockSparseTensorDescriptor",     {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorCreateBlockSparseContraction",           {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
+  {"cutensorBlockSparseContract",                    {"",                                                    "", CONV_LIB_FUNC, API_TENSOR, 2, UNSUPPORTED}},
 };
 
 const std::map<llvm::StringRef, cudaAPIversions> CUDA_TENSOR_FUNCTION_VER_MAP {
@@ -148,14 +154,20 @@ const std::map<llvm::StringRef, cudaAPIversions> CUDA_TENSOR_FUNCTION_VER_MAP {
   {"cutensorMgCreateContractionPlan",                {CUTENSOR_1400, CUDA_0,        CUDA_0        }},
   {"cutensorMgDestroyContractionPlan",               {CUTENSOR_1400, CUDA_0,        CUDA_0        }},
   {"cutensorMgContraction",                          {CUTENSOR_1400, CUDA_0,        CUDA_0        }},
+  {"cutensorCreateContractionTrinary",               {CUTENSOR_2200, CUDA_0,        CUDA_0        }},
+  {"cutensorContractTrinary",                        {CUTENSOR_2200, CUDA_0,        CUDA_0        }},
+  {"cutensorCreateBlockSparseTensorDescriptor",      {CUTENSOR_2300, CUDA_0,        CUDA_0        }},
+  {"cutensorDestroyBlockSparseTensorDescriptor",     {CUTENSOR_2300, CUDA_0,        CUDA_0        }},
+  {"cutensorCreateBlockSparseContraction",           {CUTENSOR_2300, CUDA_0,        CUDA_0        }},
+  {"cutensorBlockSparseContract",                    {CUTENSOR_2300, CUDA_0,        CUDA_0        }},
 };
 
 const std::map<llvm::StringRef, hipAPIversions> HIP_TENSOR_FUNCTION_VER_MAP {
   {"hiptensorCreate",                                {HIP_5070,      HIP_0,         HIP_0         }},
   {"hiptensorDestroy",                               {HIP_5070,      HIP_0,         HIP_0         }},
-  {"hiptensorInitTensorDescriptor",                  {HIP_5070,      HIP_0,         HIP_0         }},
+  {"hiptensorInitTensorDescriptor",                  {HIP_5070,      HIP_0,         HIP_7000      }},
   {"hiptensorPermutation",                           {HIP_6010,      HIP_0,         HIP_0         }},
-  {"hiptensorContraction",                           {HIP_6010,      HIP_0,         HIP_0         }},
+  {"hiptensorContraction",                           {HIP_6010,      HIP_0,         HIP_7000      }},
   {"hiptensorReduction",                             {HIP_6030,      HIP_0,         HIP_0         }},
   {"hiptensorGetErrorString",                        {HIP_5070,      HIP_0,         HIP_0         }},
   {"hiptensorGetHiprtVersion",                       {HIP_5070,      HIP_0,         HIP_0         }},
@@ -165,6 +177,44 @@ const std::map<llvm::StringRef, hipAPIversions> HIP_TENSOR_FUNCTION_VER_MAP {
   {"hiptensorLoggerSetLevel",                        {HIP_5070,      HIP_0,         HIP_0         }},
   {"hiptensorLoggerSetMask",                         {HIP_5070,      HIP_0,         HIP_0         }},
   {"hiptensorLoggerForceDisable",                    {HIP_5070,      HIP_0,         HIP_0         }},
+  {"hiptensorHandleResizePlanCache",                 {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorHandleWritePlanCacheToFile",            {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorHandleReadPlanCacheFromFile",           {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorWriteKernelCacheToFile",                {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorReadKernelCacheFromFile",               {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreateTensorDescriptor",                {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorDestroyTensorDescriptor",               {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreateContraction",                     {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorDestroyOperationDescriptor",            {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorOperationDescriptorSetAttribute",       {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorOperationDescriptorGetAttribute",       {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreatePlanPreference",                  {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorDestroyPlanPreference",                 {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorPlanPreferenceSetAttribute",            {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorPlanGetAttribute",                      {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorEstimateWorkspaceSize",                 {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreatePermutation",                     {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreatePlan",                            {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorDestroyPlan",                           {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorContract",                              {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorPermute",                               {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreateElementwiseBinary",               {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorElementwiseBinaryExecute",              {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreateElementwiseTrinary",              {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorElementwiseTrinaryExecute",             {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorCreateReduction",                       {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorReduce",                                {HIP_7000,      HIP_0,         HIP_0         }},
+  {"hiptensorGetVersion",                            {HIP_7020,      HIP_0,         HIP_0,        HIP_7020}},
+};
+
+const std::map<llvm::StringRef, cudaAPIChangedVersions> CUDA_TENSOR_FUNCTION_CHANGED_VER_MAP {
+  {"cutensorCreate",                                 {CUTENSOR_2000}},
+  {"cutensorDestroy",                                {CUTENSOR_2000}},
+};
+
+const std::map<llvm::StringRef, hipAPIChangedVersions> HIP_TENSOR_FUNCTION_CHANGED_VER_MAP {
+  {"hiptensorCreate",                                {HIP_7000}},
+  {"hiptensorDestroy",                               {HIP_7000}},
 };
 
 const std::map<unsigned int, llvm::StringRef> CUDA_TENSOR_API_SECTION_MAP {
